#
# spec file for package electricsheep
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Summary:  Screensaver showing collective dreams of sleeping computers
Name:     electricsheep
Version:  3.0.2
Release:  5%{?dist}
License:  GPL-2.0
URL:      https://electricsheep.org
Source:   %{name}-%{version}.tar.xz

# pkg-config exposes lua instead of lua5.1
Patch2:   %{name}-configure.patch
# for kde desktop file
Patch3:   %{name}-Makefile.patch
Patch4:	  109-modified.patch

Requires:       curl
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel >= 1.41
BuildRequires:  compat-lua-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
#BuildRequires:  compat-ffmpeg4-devel
BuildRequires:  ffmpeg-devel
BuildRequires:  flam3
BuildRequires:  flam3-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  GLee-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcurl-devel
BuildRequires:  libgtop2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libX11-devel
BuildRequires:  libXrender-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  tinyxml-devel
BuildRequires:  wxGTK3-devel
BuildRequires:  xz

%description
Electric sheep is the collective dream of sleeping computers
from all over the internet. Less poetically, it is an Internet server and
xscreensaver module that displays MPEG video of an animated fractal flame.
In the background, it contributes render cycles to the next animation.
Periodically, it uploads completed frames to the server, where they are
compressed for distribution to all clients.

%prep
%setup -q -n client_generic
%patch2
%patch3 -p1
%patch4 -p2

%build
sed -i 's|wx-config|wx-config-3.0|g' configure.ac

# fix version number
sed -i 's|2.7b33-svn|%{version}-git|g' configure.ac

export PKG_CONFIG_PATH=%{_libdir}/pkgconfig:%{_libdir}/compat-ffmpeg4/pkgconfig/

#I am in debt with Arch Linux folks
#+https://projects.archlinux.org/svntogit/community.git/commit/trunk?h=packages/electricsheep&id=88fd348d3434960902e4484d3ef654e53a591146
sed -i -e 's/AM_PROG_CC_STDC/AC_PROG_CC/' configure.ac
sed -i '12 i#include <cstdio>' Common/Singleton.h
#was compile-blocking (thanks ArchL.)
sed -i '\|-I /usr/include/libavutil|d;28s| \\$||' MSVC/SettingsGUI/Makefile.am
#sed -i 's|docdir = $(prefix)/share/doc/$(PACKAGE)-$(VERSION)|docdir = $(prefix)/share/doc/packages/$(PACKAGE)|' Makefile.am
sed -i 's|docdir = $(prefix)/share/doc/$(PACKAGE)-$(VERSION)|docdir = $(prefix)/share/doc/$(PACKAGE)|' Makefile.am
mkdir -p m4
autoupdate
./autogen.sh
export CPPFLAGS="$CPPFLAGS -DUSE_NEW_FFMPEG_API=1 -DGL_GLEXT_PROTOTYPES"
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -lpthread"

%configure --docdir=%{_docdir}
make %{?_smp_mflags} VERBOSE=1

%install
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_datadir}/applications/*.desktop
cat menu-entries/ElectricSheep.desktop > %{buildroot}%{_datadir}/applications/electricsheep.desktop
desktop-file-validate %{buildroot}/%{_datadir}/applications/electricsheep.desktop

sed -i '1i#! /bin/bash\n' %{buildroot}%{_bindir}/electricsheep-saver
rm -rf %{buildroot}%{_datadir}/applications/screensavers/

find %{buildroot}/%{_docdir}/%{name} -type f -empty -delete
#
%ifarch x86_64 aarch64
mkdir -p %{buildroot}%{_libdir}
mv %{buildroot}/usr/lib/gnome-screensaver %{buildroot}%{_libdir}/
%endif

%fdupes %{buildroot}%{_datadir}

%files
%defattr(-, root, root)
%{_bindir}/*
%{_libdir}/gnome-screensaver/*
%{_datadir}/kde4/services/ScreenSavers/*
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.xpm
%doc %{_docdir}/%{name}/Instructions.rtf
%doc %{_docdir}/%{name}/License.rtf

%changelog
* Tue May 24 2022 josef radinger <cheese@nosuchhost.net> - 3.0.2-5
- patch for ffmpeg5 taken from https://patch-diff.githubusercontent.com/raw/scottdraves/electricsheep/pull/109.patch
  slightly modified

* Fri Nov 06 2020 josef radinger <cheese@nosuchhost.net> - 3.0.2-4
- fix build for aarch64

* Sat Dec 07 2019 josef radinger <cheese@nosuchhost.net> - 3.0.2-3
- change URL
- remove BUILDROOT-definition
- buildrequires desktop-file-utils
- a litte bit of spec-file cleanup
- remove screensaver-desktop-file
- fix license (gpl2 instead of gplv2+)

* Thu May 09 2019 josef radinger <cheese@nosuchhost.net> - 3.0.2-2
- remove Group from spec-file
- remove post and postun-scripts

* Wed May 01 2019 josef radinger <cheese@nosuchhost.net> - 3.0.2-1
- bump version
- patch4 no longer needed
- add -DGL_GLEXT_PROTOTYPES to fix compile
- add -lpthread to fix linking
- clean specfile
- fix version number

* Wed Oct 26 2016 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.151-5
- update ffmpeg.patch

* Tue Jul 12 2016 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.151-4
- add patch4

* Sun Jun 29 2014 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.151-3
- rebuild with dist-flag set

* Sun Mar 16 2014 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.151-2
- rebuild
- wx 3.0

* Sat Mar 08 2014 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.151-1
- bump version
- massage patch for Makefile

* Fri Mar 07 2014 josef radinger <cheese@nosuchhost.net> - 2.7b33svn.139-2.3
- rebuild for fedora
- fix lua-5.1
- add BuildRequires GLee-devel
- fix docdir

* Sun Apr 28 2013 fa0sck@gmail.com
- New version: 2.7b33-svn (http://code.google.com/p/electricsheep/)
  Tue Sep  4 00:00:00 UTC 2007 - LenzGr
- Initial build 2.6.8 (?).
